pub enum ReflectionAdmissionDisposition {
Reject,
Quarantine,
}Expand description
Reflection admission outcome for non-admitted memory candidates.
Variants
Reject
The candidate is unsafe to retain as a reflection memory.
Quarantine
The candidate is not admissible, but the raw reflection should be retained.