pub enum ReflectionReportStatus {
CandidateOnly,
Quarantined,
}Expand description
Stable status for reflect outputs.
Variants
CandidateOnly
Model output parsed and any durable memory rows are still candidates.
Quarantined
Model output was rejected and a quarantine audit row was written.